==> flutterskel-0.0.6.tar.gz: lib/widgets/stateless/RawStatelessWidgetClass.dart <==
import 'package:flutter/widgets.dart';
import 'package:flutterskel/configuration/ConfigurationRepository.dart';
import 'package:flutterskel/datasource/DataSource.dart';
import 'package:flutterskel/resources/colors/ColorResources.dart';
import 'package:flutterskel/resources/dimensions/DimensionResources.dart';
import 'package:flutterskel/resources/fonts/FontResources.dart';
import 'package:flutterskel/resources/icons/IconResources.dart';
import 'package:flutterskel/resources/images/ImageResources.dart';
import 'package:flutterskel/resources/strings/StringsRepository.dart';
import 'package:flutterskel/resources/themes/ThemeRepository.dart';
import 'package:flutterskel/resources/themes/ThemeResources.dart';
import 'package:flutterskel/routing/page/PageRouter.dart';
import 'package:flutterskel/routing/url/UrlRouter.dart';
import 'package:flutterskel/userinformation/UserInformationRepository.dart';
import 'package:provider/provider.dart';

/// Raw abstract State class
/// This class should only be extended by an abstract class within the app, which fills in all the info except [StateWidget]
/// [StateWidget] should be filled in by the final StatefulWidget class
abstract class RawBaseStatelessWidget<
                // Data
                Data extends DataSource,
                // Routing
                URouter extends UrlRouter,
                PRouter extends PageRouter,
                // Configuration
                ConfigRepo extends ConfigurationRepository,
                // User Information
                UserRepo extends UserInformationRepository,
                // Strings
                StringRepo extends StringsRepository,
                // Themes (Fonts/Dimensions/Colors)
                ThemeRepo extends ThemeRepository,
                Theme extends ThemeResources,
                Colors extends ColorResources,
                Dimensions extends DimensionResources,
                Fonts extends FontResources,
                // Images and Icons
                Images extends ImageResources,
                Icons extends IconResources> extends StatelessWidget {

  Data getDataSource(BuildContext context) => Provider.of<Data>(context);

  URouter urlRouter(BuildContext context) => Provider.of<URouter>(context);

  PRouter pageRouter(BuildContext context) => Provider.of<PRouter>(context);

  Images images(BuildContext context) => Provider.of<Images>(context);

  ConfigRepo configuration(BuildContext context) => Provider.of<ConfigRepo>(context);

  UserRepo userInformation(BuildContext context) => Provider.of<UserRepo>(context);

  StringRepo strings(BuildContext context) => Provider.of<StringRepo>(context);

  ThemeRepo themeRepo(BuildContext context) => Provider.of<ThemeRepo>(context);

  Theme theme(BuildContext context) => Provider.of<Theme>(context);

  Colors colors(BuildContext context) => Provider.of<Colors>(context);

  Dimensions dimensions(BuildContext context) => Provider.of<Dimensions>(context);

  Fonts fonts(BuildContext context) => Provider.of<Fonts>(context);

  Icons icons(BuildContext context) => Provider.of<Icons>(context);

}

==> flutterskel-0.0.7.tar.gz: lib/widgets/stateless/RawStatelessWidgetClass.dart <==
import 'package:flutter/widgets.dart';
import 'package:flutterskel/resources/colors/ColorResources.dart';
import 'package:flutterskel/resources/fonts/FontResources.dart';
import 'package:flutterskel/resources/strings/StringsRepository.dart';
import 'package:flutterskel/resources/themes/ThemeRepository.dart';
import 'package:flutterskel/resources/themes/ThemeResources.dart';
import 'package:flutterskel/routing/page/PageRouter.dart';
import 'package:flutterskel/routing/url/UrlRouter.dart';
import 'package:flutterskel/userinformation/UserInformationRepository.dart';
import 'package:flutterskel/configuration/ConfigurationRepository.dart' as config;
import 'package:provider/provider.dart';

/// Raw abstract State class
/// This class should only be extended by an abstract class within the app, which fills in all the info except [StateWidget]
/// [StateWidget] should be filled in by the final StatefulWidget class
abstract class RawBaseStatelessWidget<
                // Data
                DataSource,
                // Routing
                URouter extends UrlRouter,
                PRouter extends PageRouter,
                // Configuration
                ConfigurationRepository extends config.ConfigurationRepository,
                Configuration,
                // User Information
                UserRepo extends UserInformationRepository,
                // Strings
                StringRepo extends StringsRepository,
                StringsClass,
                // Themes (Fonts/Dimensions/Colors)
                ThemeRepo extends ThemeRepository,
                Theme extends ThemeResources,
                Colors extends ColorResources,
                Dimensions,
                Fonts extends FontResources,
                // Images and Icons
                Images,
                Icons> extends StatelessWidget {

  DataSource getDataSource(BuildContext context) => Provider.of<DataSource>(context);

  URouter urlRouter(BuildContext context) => Provider.of<URouter>(context);

  PRouter pageRouter(BuildContext context) => Provider.of<PRouter>(context);

  Images images(BuildContext context) => Provider.of<Images>(context);

  // Configuration
  ConfigurationRepository getConfigurationRepository(BuildContext context) => Provider.of<ConfigurationRepository>(context);
  Configuration configuration(BuildContext context) => getConfigurationRepository(context).configuration;

  UserRepo userInformation(BuildContext context) => Provider.of<UserRepo>(context);

  StringsClass strings(BuildContext context) => Provider.of<StringRepo>(context).strings;

  ThemeRepo themeRepo(BuildContext context) => Provider.of<ThemeRepo>(context);

  Theme theme(BuildContext context) => Provider.of<Theme>(context);

  Colors colors(BuildContext context) => Provider.of<Colors>(context);

  Dimensions dimensions(BuildContext context) => Provider.of<Dimensions>(context);

  Fonts fonts(BuildContext context) => Provider.of<Fonts>(context);

  Icons icons(BuildContext context) => Provider.of<Icons>(context);

}
